@@ -271,11 +271,11 @@ class LambdaToDynamoDBProps:
         :summary: The properties for the LambdaToDynamoDB Construct
         '''
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = TableProps(**dynamo_table_props)
+            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(LambdaToDynamoDBProps.__init__)
             check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
